@@ -29,6 +29,17 @@ class Core(ispyb.interface.core.IF):
         ('title',None), ('beamline_operator',None), ('nb_shifts',None), ('scheduled',None), ('used_flag',None),
         ('comments',None), ('external_pk_id',None), ('external_pk_uuid',None)])
 
+  _person_params =\
+    StrictOrderedDict([('id',None), ('laboratory_id',None), ('family_name',None), ('given_name',None), ('title',None),
+                         ('email_address',None), ('phone_number',None), ('login',None), ('external_pk_id',None),
+                         ('external_pk_uuid',None)])
+
+  _proposal_has_person_params =\
+    StrictOrderedDict([('id',None), ('proposal_id',None), ('person_id',None), ('role',None)])
+
+  _session_has_person_params =\
+    StrictOrderedDict([('session_id',None), ('person_id',None), ('role',None), ('remote',None)])
+
   _sample_params =\
     StrictOrderedDict([('id',None), ('crystalid',None), ('containerid',None), ('name',None), ('code',None),
                          ('location',None), ('holder_length',None), ('loop_length',None), ('loop_type',None),
@@ -38,14 +49,42 @@ class Core(ispyb.interface.core.IF):
   def get_session_for_proposal_code_number_params(cls):
     return copy.deepcopy(cls._session_for_proposal_code_number_params)
 
+  @classmethod
+  def get_person_params(cls):
+    return copy.deepcopy(cls._person_params)
+
+  @classmethod
+  def get_person_params(cls):
+    return copy.deepcopy(cls._person_params)
+
+  @classmethod
+  def get_proposal_has_person_params(cls):
+    return copy.deepcopy(cls._proposal_has_person_params)
+
+  @classmethod
+  def get_session_has_person_params(cls):
+    return copy.deepcopy(cls._session_has_person_params)
+
   @classmethod
   def get_sample_params(cls):
     return copy.deepcopy(cls._sample_params)
 
   def upsert_session_for_proposal_code_number(self, values):
-    '''Insert a new session for a proposal with given proposal code and number.'''
+    '''Insert or update a session for a certain proposal with given proposal code and number.'''
     return self.get_connection().call_sp_write('upsert_session_for_proposal_code_number', values)
 
+  def upsert_person(self, values):
+    '''Insert or update a person'''
+    return self.get_connection().call_sp_write('upsert_person', values)
+
+  def upsert_session_has_person(self, values):
+    '''Insert or update a session-person association'''
+    return self.get_connection().call_sp_write('upsert_session_has_person', values)
+
+  def upsert_proposal_has_person(self, values):
+    '''Insert or update a proposal-person association'''
+    return self.get_connection().call_sp_write('upsert_proposal_has_person', values)
+
   def upsert_sample(self, values):
     '''Insert or update sample.'''
     return self.get_connection().call_sf_write('upsert_sample', values)
